from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.RepeatedCapability import RepeatedCapability
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Zone:
	"""Zone commands group definition. 2 total commands, 2 Sub-groups, 0 group commands
	Repeated Capability: ZoneNull, default value after init: ZoneNull.Nr0"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("zone", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_zoneNull_get', 'repcap_zoneNull_set', repcap.ZoneNull.Nr0)

	def repcap_zoneNull_set(self, enum_value: repcap.ZoneNull) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to ZoneNull.Default
		Default value after init: ZoneNull.Nr0"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_zoneNull_get(self) -> repcap.ZoneNull:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def bit(self):
		"""bit commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bit'):
			from .Zone_.Bit import Bit
			self._bit = Bit(self._core, self._base)
		return self._bit

	@property
	def count(self):
		"""count commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_count'):
			from .Zone_.Count import Count
			self._count = Count(self._core, self._base)
		return self._count

	def clone(self) -> 'Zone':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Zone(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
