from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class M11T:
	"""M11T commands group definition. 5 total commands, 5 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("m11T", core, parent)

	@property
	def foffset(self):
		"""foffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_foffset'):
			from .M11T_.Foffset import Foffset
			self._foffset = Foffset(self._core, self._base)
		return self._foffset

	@property
	def lpair(self):
		"""lpair commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_lpair'):
			from .M11T_.Lpair import Lpair
			self._lpair = Lpair(self._core, self._base)
		return self._lpair

	@property
	def mbytes(self):
		"""mbytes commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mbytes'):
			from .M11T_.Mbytes import Mbytes
			self._mbytes = Mbytes(self._core, self._base)
		return self._mbytes

	@property
	def rframe(self):
		"""rframe commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rframe'):
			from .M11T_.Rframe import Rframe
			self._rframe = Rframe(self._core, self._base)
		return self._rframe

	@property
	def slot(self):
		"""slot commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_slot'):
			from .M11T_.Slot import Slot
			self._slot = Slot(self._core, self._base)
		return self._slot

	def clone(self) -> 'M11T':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = M11T(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
