from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pcrs:
	"""Pcrs commands group definition. 4 total commands, 4 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("pcrs", core, parent)

	@property
	def apConf(self):
		"""apConf commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_apConf'):
			from .Pcrs_.ApConf import ApConf
			self._apConf = ApConf(self._core, self._base)
		return self._apConf

	@property
	def nid(self):
		"""nid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nid'):
			from .Pcrs_.Nid import Nid
			self._nid = Nid(self._core, self._base)
		return self._nid

	@property
	def nidpcrs(self):
		"""nidpcrs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nidpcrs'):
			from .Pcrs_.Nidpcrs import Nidpcrs
			self._nidpcrs = Nidpcrs(self._core, self._base)
		return self._nidpcrs

	@property
	def rpower(self):
		"""rpower commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rpower'):
			from .Pcrs_.Rpower import Rpower
			self._rpower = Rpower(self._core, self._base)
		return self._rpower

	def clone(self) -> 'Pcrs':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Pcrs(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
