from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Correlation:
	"""Correlation commands group definition. 3 total commands, 3 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("correlation", core, parent)

	@property
	def coefficient(self):
		"""coefficient commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_coefficient'):
			from .Correlation_.Coefficient import Coefficient
			self._coefficient = Coefficient(self._core, self._base)
		return self._coefficient

	@property
	def phase(self):
		"""phase commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_phase'):
			from .Correlation_.Phase import Phase
			self._phase = Phase(self._core, self._base)
		return self._phase

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .Correlation_.State import State
			self._state = State(self._core, self._base)
		return self._state

	def clone(self) -> 'Correlation':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Correlation(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
