from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Arrival:
	"""Arrival commands group definition. 4 total commands, 3 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("arrival", core, parent)

	@property
	def angle(self):
		"""angle commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_angle'):
			from .Arrival_.Angle import Angle
			self._angle = Angle(self._core, self._base)
		return self._angle

	@property
	def spread(self):
		"""spread commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_spread'):
			from .Arrival_.Spread import Spread
			self._spread = Spread(self._core, self._base)
		return self._spread

	@property
	def zenith(self):
		"""zenith commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_zenith'):
			from .Arrival_.Zenith import Zenith
			self._zenith = Zenith(self._core, self._base)
		return self._zenith

	def clone(self) -> 'Arrival':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Arrival(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
